"""
    Scrapes heise.de/newsticker/classic/
    for headlines and corresponding urls
    @date: 2019-11-12
"""

import requests
import lxml
import bs4
import re
import json

print('Grabbing headlines from Heise')

content_url = 'https://www.heise.de/newsticker/classic/'
base_url = 'https://heise.de'
file_name = 'data/heise.json'
regex = '/(^\/meldung|^\/security\/meldung|^\/newsticker\/meldung|^\/developer\/meldung|^\/developer\/artikel|\/ct\/artikel|^\/make\/artikel|\/security\/artikel)/'
allowed_paths = [
    '/meldung',
    '/ct/artikel',
    '/developer/artikel',
    '/developer/meldung',
    '/make/artikel',
    '/newsticker/meldung',
    '/security/meldung'
]
media_identifier = 'heise'
counter = 0
data = []


html = requests.get(content_url) # read the url
soup = bs4.BeautifulSoup(html.text, 'lxml') # create a DOM-like object
articles = soup.find_all('article')

for h in articles:
    counter += 1
    sub_soup = bs4.BeautifulSoup(str(h), 'lxml')
    anchors = sub_soup.find_all('a')
    for a in anchors:
        tiny_soup = bs4.BeautifulSoup(str(a), 'lxml')
        if a['href'].startswith(tuple(allowed_paths)):
            # skip external links and special pages
            x = {
                'id': counter,
                'source': media_identifier,
                'url': base_url + a['href'],
                'title': a['title']
            }
            data.append(x)

with open(file_name, 'w', encoding='utf-8') as f:
    json.dump(data, f, ensure_ascii=False, indent=4)
